@@ -1,9 +1,9 @@
-// SPDX-FileCopyrightText: 2021 Mikhail Zolotukhin <mail@genda.life>
+// SPDX-FileCopyrightText: 2021 Mikhail Zolotukhin <mail@gikari.com>
 //
 // SPDX-License-Identifier: MIT
 
-import { ConfigImpl } from "./config";
 import { Controller, ControllerImpl } from "./controller";
+import { TSProxy } from "./extern/proxy";
 import { LogImpl } from "./util/log";
 
 /**
@@ -13,16 +13,19 @@ import { LogImpl } from "./util/log";
  */
 export function init(
   qmlObjects: Bismuth.Qml.Main,
-  kwinScriptingApi: KWin.Api
-): Controller {
-  const config = new ConfigImpl(kwinScriptingApi);
-  const logger = new LogImpl(config);
+  kwinScriptingApi: KWin.Api,
+  proxy: TSProxy
+): Controller | null {
+  const config = proxy.jsConfig();
+
+  const logger = new LogImpl(proxy);
 
   const controller = new ControllerImpl(
     qmlObjects,
     kwinScriptingApi,
     config,
-    logger
+    logger,
+    proxy
   );
 
   controller.start();
